/*
 IBMDoK - a kicker applet for IBM sensors
 (c) 2006 by Marco Kraus
 http://www.kraus.tk
 Published under GPL2. See COPYING
*/

#include "ibmdok.h"

IBMDoK::IBMDoK(const QString& configFile, Type type, int actions, QWidget *parent, const char *name) : KPanelApplet(configFile, type, actions, parent, name)
{
    // Get the current application configuration handle
    ksConfig = config();

    setFrameStyle( QFrame::MenuBarPanel | Plain );
    //setFrameStyle( QFrame::StyledPanel | Raised );
    setBackgroundMode(Qt::NoBackground);
    //setSizePolicy( QSizePolicy(QSizePolicy::BothDirections) );

    Data = new KickerData(this);

    // set up timer to update data frequently
    QTimer *timer = new QTimer( );
    connect( timer, SIGNAL(timeout()), this, SLOT(readData()) );
    timer->start( 1000*_UPDATE_, false ); // 1000 = one second

    this->readData();  //initial read in
}

IBMDoK::~IBMDoK()
{
}

void IBMDoK::readData()
{
    char ProcFile[] = _THERMALFILE_;
    char b[128];

    FILE *stream;
    if(! (stream = fopen(ProcFile, "r")) )
    {
          KMessageBox::information(0, "Error reading thermal information from proc FS\n");
          return;
    }

    fgets(b, 128, stream);
    SensorRawValues = b;
    SensorRawValues = SensorRawValues.simplifyWhiteSpace();

   this->updateDisplay();
}

void IBMDoK::updateDisplay()
{
    //KMessageBox::information(0, "Data:"+SensorRawValues);

    QString vals;

    QString CPUval = SensorRawValues.section(" ",1,1);
    QString HDDval = SensorRawValues.section(" ",2,2);
    QString GPUval = SensorRawValues.section(" ",4,4);
    QString BATval = SensorRawValues.section(" ",5,5);

    if( CPUval.toInt() < _CPULIMIT_ ) CPUval = "<font color='darkgreen'>"+CPUval+" C</font>";
    else CPUval = "<font color='darkred'>"+CPUval+"</font>";

    if( HDDval.toInt() < _HDDLIMIT_ ) HDDval = "<font color='darkgreen'>"+HDDval+" C</font>";
    else HDDval = "<font color='darkred'>"+HDDval+"</font>";

    if( GPUval.toInt() < _GPULIMIT_ ) GPUval = "<font color='darkgreen'>"+GPUval+" C</font>";
    else GPUval = "<font color='darkred'>"+GPUval+"</font>";

    if( BATval.toInt() < _BATLIMIT_ ) BATval = "<font color='darkgreen'>"+BATval+" C</font>";
    else BATval = "<font color='darkred'>"+BATval+"</font>";

    Data->GPULabel->setText(GPUval);
    Data->CPULabel->setText(CPUval);
    Data->HDDLabel->setText(HDDval);
    Data->BATLabel->setText(BATval);

    emit updateLayout();
}

void IBMDoK::about()
{
   KAboutData  *_aboutData = new KAboutData("IBMDoK", I18N_NOOP("IBMDoK"),
                             "0.1", I18N_NOOP("IBMDoK.\n\n"
                             "Kicker applet for IBM sensors."),
                             KAboutData::License_GPL, "(c) 2006, Marco Kraus");

                _aboutData->addAuthor("Marco Kraus", 0, "ibmdok@linuxstuff.de");

  KAboutApplication dialog(_aboutData);
  dialog.exec();
}


void IBMDoK::preferences()
{
    KMessageBox::information(0, i18n("Will be implemented in next version"));
}

int IBMDoK::widthForHeight(int height) const
{
    return width();
}

int IBMDoK::heightForWidth(int width) const
{
    return height();
}

void IBMDoK::resizeEvent(QResizeEvent *e)
{
}

extern "C"
{
    KPanelApplet* init( QWidget *parent, const QString& configFile)
    {
        KGlobal::locale()->insertCatalogue("IBMDoK");
        return new IBMDoK(configFile, KPanelApplet::Normal, KPanelApplet::About|KPanelApplet::Preferences, parent, "IBMDoK");
    }
}
